@@ -17,7 +17,7 @@ extern crate alloc;
 #[cfg(feature = "std")]
 extern crate std;
 
-#[cfg(rustdoc)]
+#[cfg(any(feature = "std", rustdoc))]
 use alloc::vec::Vec;
 
 pub use crate::iterators::*;
@@ -555,11 +555,35 @@ impl<T, const N: usize> StaticVec<T, { N }> {
   #[inline(always)]
   pub fn try_extend_from_slice(&mut self, other: &[T]) -> Result<(), &'static str>
   where T: Copy {
-    if self.remaining_capacity() < other.len() {
-      Err("Insufficient remaining capacity!")
-    } else {
-      self.extend_from_slice(other);
-      Ok(())
+    let added_length = other.len();
+    if self.remaining_capacity() < added_length {
+      return Err("Insufficient remaining capacity!");
+    }
+    unsafe {
+      other
+        .as_ptr()
+        .copy_to_nonoverlapping(self.as_mut_ptr().add(self.length), added_length);
+    }
+    self.length += added_length;
+    Ok(())
+  }
+
+  ///Returns a [Vec](alloc::vec::Vec) containing the contents of the StaticVec instance.
+  ///The returned [Vec](alloc::vec::Vec) will initially have the same value for
+  ///[len](alloc::vec::Vec::len) and [capacity](alloc::vec::Vec::capacity) as the source StaticVec.
+  #[cfg(feature = "std")]
+  #[doc(cfg(feature = "std"))]
+  #[inline(always)]
+  pub fn into_vec(&mut self) -> Vec<T> {
+    let mut res = Vec::<T>::with_capacity(N);
+    unsafe {
+      self
+        .as_ptr()
+        .copy_to_nonoverlapping(res.as_mut_ptr(), self.length);
+      res.set_len(self.length);
+      self.length = 0;
+      mem::forget(self.as_mut_slice());
+      res
     }
   }
 
