@@ -6,14 +6,14 @@ use core::mem::MaybeUninit;
 #[inline(always)]
 pub(crate) fn distance_between<T>(dest: *const T, origin: *const T) -> usize {
   unsafe {
-    return if intrinsics::size_of::<T>() > 0 {
+    if intrinsics::size_of::<T>() > 0 {
       intrinsics::exact_div(
         (dest as usize).wrapping_sub(origin as usize),
         intrinsics::size_of::<T>(),
       )
     } else {
       (dest as usize).wrapping_sub(origin as usize)
-    };
+    }
   }
 }
 
