@@ -2,6 +2,19 @@
 
 use staticvec::*;
 
+#[derive(Debug)]
+struct Struct {
+  s: &'static str,
+}
+
+impl Drop for Struct {
+  fn drop(&mut self) {
+    //This won't do anything observable in the test context, but it
+    //works as a placeholder.
+    println!("Dropping Struct with value: {}", self.s)
+  }
+}
+
 #[cfg(feature = "std")]
 use std::io::{IoSlice, IoSliceMut, Read, Write};
 
@@ -35,13 +48,13 @@ fn bounds_to_string() {
   let mut it = v.iter();
   it.next_back();
   assert_eq!(
-    "Current value of `start`: 1\nCurrent value of `end`: 4",
+    "Current value of element at `start`: 1\nCurrent value of element at `end`: 4",
     it.bounds_to_string()
   );
   let mut itm = v.iter_mut();
   itm.next_back();
   assert_eq!(
-    "Current value of `start`: 1\nCurrent value of `end`: 4",
+    "Current value of element at `start`: 1\nCurrent value of element at `end`: 4",
     itm.bounds_to_string()
   );
 }
@@ -218,6 +231,25 @@ fn is_not_full() {
   assert!(v.is_not_full());
 }
 
+#[test]
+fn into_vec() {
+  let mut v = staticvec![
+    Box::new(Struct { s: "AAA" }),
+    Box::new(Struct { s: "BBB" }),
+    Box::new(Struct { s: "CCC" })
+  ];
+  let vv = v.into_vec();
+  assert_eq!(vv.capacity(), 3);
+  assert_eq!(vv.len(), 3);
+  assert_eq!(v.capacity(), 3);
+  assert_eq!(v.len(), 0);
+  v.push(Box::new(Struct { s: "AAA" }));
+  v.push(Box::new(Struct { s: "BBB" }));
+  v.push(Box::new(Struct { s: "CCC" }));
+  assert_eq!(v.capacity(), 3);
+  assert_eq!(v.len(), 3);
+}
+
 #[test]
 fn last() {
   let v = staticvec![1, 2, 3];
